@@ -5,7 +5,7 @@ register = template.Library()
 
 
 @register.filter
-def stripAndsplit(string, sep):
+def stripAndsplit(string, sep):  # noqa
     """Return the string split by sep.
 
     Example usage: {{ value|split:"/" }}
